@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ajaxManager.php 2354 2009-09-25 05:33:35Z fishbone $
+ * @version    SVN: $Id: ajaxManager.php 5009 2012-07-03 13:55:38Z fishbone $
  * @link       http://www.magic3.org
  */
 class AjaxManager
@@ -102,5 +102,17 @@ class AjaxManager
 		$retData = $json->encode($this->jsonData);
 		if (!empty($retData)) header('X-JSON: ' . '(' . $retData . ')');
 	}
+	/**
+	 * JSONデータを作成
+	 *
+	 * @param object $obj			JSONデータに変換するデータ
+	 * @return string				JSON型文字列
+	 */
+	function createJsonString($obj)
+	{
+		require_once(M3_SYSTEM_LIB_PATH . '/JSON.php');
+		$json = new Services_JSON();
+		return $json->encode($obj);
+	}
 }
 ?>
