@@ -5,12 +5,13 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fckconfig.js 3743 2010-10-27 02:29:43Z fishbone $
+ * @version    SVN: $Id: fckconfig.js 5494 2012-12-30 03:23:17Z fishbone $
  * @link       http://www.magic3.org
  */
-FCKConfig.EnterMode = 'div' ;			// p | div | br
+//FCKConfig.EnterMode = 'div' ;			// p | div | br
+FCKConfig.EnterMode = 'br' ;			// p | div | br		// P,DIVタグで囲まない
 FCKConfig.ShiftEnterMode = 'br' ;	// p | div | br
 
 FCKConfig.LinkBrowser = false ;
