@@ -143,11 +143,11 @@ class event_mainTopWidgetContainer extends event_mainBaseWidgetContainer
 				return 'list.tmpl.html';		// トップ画面記事一覧
 			} else {
 				$this->viewMode = 10;					// 表示モード(記事単体表示)
-				if ($this->_renderType == M3_RENDER_BOOTSTRAP){
-					return 'single_bootstrap.tmpl.html';		// 記事詳細
-				} else {
+//				if ($this->_renderType == M3_RENDER_BOOTSTRAP){
+//					return 'single_bootstrap.tmpl.html';		// 記事詳細
+//				} else {
 					return 'single.tmpl.html';		// 記事詳細
-				}
+//				}
 			}
 		}
 	}
@@ -533,6 +533,17 @@ class event_mainTopWidgetContainer extends event_mainBaseWidgetContainer
 							'keywords' => $this->headKeyword);
 		return $headData;
 	}
+	/**
+	 * ウィジェットのタイトルを設定
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ウィジェットのタイトル名
+	 */
+	function _setTitle($request, &$param)
+	{
+		return $this->widgetTitle;	// ウィジェットタイトル
+	}
 	/**
 	 * 取得したコンテンツ項目をテンプレートに設定する
 	 *
@@ -545,7 +556,7 @@ class event_mainTopWidgetContainer extends event_mainBaseWidgetContainer
 	{
 		// 参照ビューカウントを更新
 		if (!$this->isSystemManageUser){		// システム運用者以上の場合はカウントしない
-			$this->gInstance->getAnalyzeManager()->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['ee_serial'], $this->currentDay, $this->currentHour);
+			$this->gInstance->getAnalyzeManager()->updateContentViewCount(event_mainCommonDef::VIEW_CONTENT_TYPE, $fetchedRow['ee_serial'], $this->currentDay, $this->currentHour);
 		}
 
 		$entryId = $fetchedRow['ee_id'];// 記事ID
